@@ -4,7 +4,6 @@ require 'aprs4r/APRS4RLogger'
 require 'aprs4r/APRS4RConfiguration'
 
 require 'aprs4r/APRSCall'
-require 'aprs4r/APRSMessage'
 
 require 'aprs4r/SocketConfiguration'
 require 'aprs4r/ISSocketConfiguration'
@@ -13,6 +12,8 @@ require 'aprs4r/AX25SocketConfiguration'
 require 'aprs4r/PluginConfiguration'
 require 'aprs4r/BeaconPluginConfiguration'
 require 'aprs4r/ProportionalBeaconPluginConfiguration'
+require 'aprs4r/StatusBeaconPluginConfiguration'
+require 'aprs4r/WeatherBeaconPluginConfiguration'
 require 'aprs4r/GatewayPluginConfiguration'
 require 'aprs4r/DigipeaterPluginConfiguration'
 require 'aprs4r/LCD4LinuxPluginConfiguration'
@@ -22,9 +23,11 @@ require 'aprs4r/MessagePluginConfiguration'
 require 'aprs4r/ISServerPluginConfiguration'
 require 'aprs4r/WeatherPluginConfiguration'
 require 'aprs4r/WMRWeatherPluginConfiguration'
-require 'aprs4r/WS2300WeatherPluginConfiguration'
+require 'aprs4r/UltimeterWeatherPluginConfiguration'
+require 'aprs4r/WM918WeatherPluginConfiguration'
 require 'aprs4r/LogPluginConfiguration'
 
+
 include APRS4R
 
 
@@ -44,6 +47,41 @@ class AbstractHandler
     return value
   end
 
+  
+  def AbstractHandler.show_timeout( cgi)
+    @@logger.info( "show_timeout( cgi)")
+
+    return cgi.h3( "ALIGN" => "center", "STYLE" => "color:red") { 
+      "Kein Profil geladen oder Zeitberschreitung!" + 
+      cgi.a( "/aprs4r-web/cgi-bin/admin.rb/setup") { "Hier laden." }
+    } 
+  end
+
+
+  def AbstractHandler.show_profile( cgi, session)
+    @@logger.info( "show_profile( cgi, session)")
+
+    if session['file']
+      return cgi.h3( "ALIGN" => "right") { "Profil: #{session['file']}" }
+    end
+
+    return ""
+  end
+
+
+  def AbstractHandler.show_changed( cgi, session)
+    @@logger.info( "show_changed( cgi, session)")
+
+    if session['changed']
+      return cgi.h3( "ALIGN" => "right", "STYLE" => "color:red") { 
+        "Achtung: Profil noch nicht gespeichert !" +
+        cgi.a( "/aprs4r-web/cgi-bin/admin.rb/setup") { "Hier speichern." }
+      } 
+    end
+
+    return ""
+  end
+
 
   def AbstractHandler.handle_input( cgi, session, items, item_name, item_types, item_prefix)
     @@logger.info( "handle_input( cgi, session, items, item_name, item_types, item_prefix)")
@@ -85,6 +123,7 @@ class AbstractHandler
         item.name = name
         item.type = type
         item.enable = false
+        item.remote = false
 
       end
       
@@ -154,8 +193,7 @@ class AbstractHandler
           elsif attribute.type == "select"
             value = field.to_s
           elsif attribute.type == "complex"
-            # TODO generic complex handling
-            value = handle_update( cgi, session, id + ":" + name, APRSMessage.new)
+            value = handle_update( cgi, session, id + ":" + name, attribute.default)
           else 
             @@logger.debug( "Unknown field type #{attribute.type}")
           end
@@ -215,11 +253,21 @@ class AbstractHandler
       
       attribute_output = ""
       attributes = configuration.attributes
+
+      @@logger.debug( "configuration: #{configuration}")
       attributes.each{ |attribute|
+
+        @@logger.debug( "attribute: #{attribute.name}")
+        @@logger.debug( "deprecated?: #{attribute.deprecated}")
         
         attribute_output += cgi.tr { 
           row_output = "" 
-          row_output += cgi.td( "WIDTH" => "130", "VALIGN" => "TOP") { "#{attribute.description}" }
+
+          if attribute.deprecated
+            row_output += cgi.td( "WIDTH" => "130", "VALIGN" => "TOP") { "#{attribute.description}*" }
+          else
+            row_output += cgi.td( "WIDTH" => "130", "VALIGN" => "TOP") { "#{attribute.description}" }
+          end
           
           if !attribute.mutable
 
@@ -285,9 +333,11 @@ class AbstractHandler
 
           elsif attribute.type == "complex"
             prefix = item_prefix + attribute.name + ":"
-            
+
             value = configuration.instance_variable_get( "@#{attribute.name}")
 
+            value = attribute.default if value.nil?
+            
             if value
               row_output += cgi.td { create_form( cgi, value, item_id, prefix, item_action, true) }
             else
@@ -340,6 +390,7 @@ class AbstractHandler
 
     if Time.new > (timestamp + 2 * 60 * 60)
       session['config'] = nil
+      session['file'] = nil
     end
 
     return session
